@@ -1,6 +1,6 @@
 package Reflex::Callback::Promise;
-BEGIN {
-  $Reflex::Callback::Promise::VERSION = '0.091';
+{
+  $Reflex::Callback::Promise::VERSION = '0.092';
 }
 # vim: ts=2 sw=2 noexpandtab
 
@@ -18,9 +18,9 @@ has queue => (
 
 # Delivering to a promise enqueues the message.
 sub deliver {
-	my ($self, $event, $arg) = @_;
+	my ($self, $event) = @_;
 	confess "promise queue overflow in $self" if (
-		push(@{$self->queue()}, { name => $event, arg => $arg }) > 100
+		push(@{$self->queue()}, $event) > 100
 	);
 }
 
@@ -69,7 +69,7 @@ Reflex::Callback::Promise - Non-callback, inline Promise adapter
 
 =head1 VERSION
 
-This document describes version 0.091, released on August 25, 2011.
+This document describes version 0.092, released on November 29, 2011.
 
 =head1 SYNOPSIS
 
