@@ -1,6 +1,6 @@
 package Reflex::POE::Postback;
-BEGIN {
-  $Reflex::POE::Postback::VERSION = '0.091';
+{
+  $Reflex::POE::Postback::VERSION = '0.092';
 }
 # vim: ts=2 sw=2 noexpandtab
 
@@ -9,6 +9,7 @@ BEGIN {
 use warnings;
 use strict;
 use Scalar::Util qw(weaken);
+use Reflex::Event::Postback;
 
 my %owner_session_ids;
 
@@ -20,10 +21,13 @@ sub new {
 
 	my $self = bless sub {
 		$POE::Kernel::poe_kernel->post(
-			$object->session_id(), "call_gate_method", $object, $method, {
+			$object->session_id(), "call_gate_method", $object, $method,
+			Reflex::Event::Postback->new(
+				_emitters => [ $object ],
+				-name     => 'postback',
 				context   => $context,
 				response  => [ @_ ],
-			},
+			)
 		);
 	}, $class;
 
@@ -71,7 +75,7 @@ Reflex::POE::Postback - Communicate with POE components expecting postbacks.
 
 =head1 VERSION
 
-This document describes version 0.091, released on August 25, 2011.
+This document describes version 0.092, released on November 29, 2011.
 
 =head1 SYNOPSIS
 
@@ -115,10 +119,10 @@ Reflex::POE::Postback when it was created.  In the case of the
 SYNOPSIS, that would be:
 
 	sub on_component_result {
-		my ($self, $arg) = @_;
+		my ($self, $event) = @_;
 
 		# Displays: 123
-		print $arg->{context}{cookie}, "\n";
+		print $event->context()->{cookie}, "\n";
 	}
 
 =head3 response
@@ -131,10 +135,10 @@ to the postback.  If we assume this postback call:
 Then the callback might look something like this:
 
 	sub on_component_result {
-		my ($self, $arg) = @_;
+		my ($self, $event) = @_;
 
 		# Displays: nine
-		print "$arg->{response}[-1]\n";
+		print $event->response()->[-1], "\n";
 	}
 
 =head1 CAVEATS
