@@ -1,6 +1,6 @@
 package Reflex::Stream;
-BEGIN {
-  $Reflex::Stream::VERSION = '0.091';
+{
+  $Reflex::Stream::VERSION = '0.092';
 }
 # vim: ts=2 sw=2 noexpandtab
 
@@ -37,7 +37,7 @@ Reflex::Stream - Buffered, translated I/O on non-blocking handles.
 
 =head1 VERSION
 
-This document describes version 0.091, released on August 25, 2011.
+This document describes version 0.092, released on November 29, 2011.
 
 =head1 SYNOPSIS
 
@@ -50,13 +50,17 @@ Reflex::Collection.
 	extends 'Reflex::Stream';
 
 	sub on_data {
-		my ($self, $args) = @_;
-		$self->put($args->{data});
+		my ($self, $event) = @_;
+		$self->put($event->octets());
 	}
 
 	sub on_error {
-		my ($self, $args) = @_;
-		warn "$args->{errfun} error $args->{errnum}: $args->{errstr}\n";
+		my ($self, $event) = @_;
+		warn(
+			$event->error_function(),
+			" error ", $event->error_number(),
+			": ", $event->error_string(),
+		);
 		$self->stopped();
 	}
 
