@@ -1,6 +1,6 @@
 package Reflex::Trait::EmitsOnChange;
-BEGIN {
-  $Reflex::Trait::EmitsOnChange::VERSION = '0.091';
+{
+  $Reflex::Trait::EmitsOnChange::VERSION = '0.092';
 }
 # vim: ts=2 sw=2 noexpandtab
 
@@ -10,6 +10,8 @@ use Scalar::Util qw(weaken);
 use Moose::Exporter;
 Moose::Exporter->setup_import_methods( with_caller => [ qw( emits ) ]);
 
+use Reflex::Event::ValueChange;
+
 has setup => (
 	isa     => 'CodeRef|HashRef',
 	is      => 'ro',
@@ -24,10 +26,10 @@ has trigger => (
 		# Weaken $meta_self so that the closure isn't permanent.
 
 		my $event;
-		#my $last_value;
+		my $old_value;
 
 		sub {
-			my ($self, $value) = @_;
+			my ($self, $new_value) = @_;
 
 			# Edge-detection.  Only emit when a value has changed.
 			# TODO - Make this logic optional.  Sometimes an application
@@ -38,19 +40,19 @@ has trigger => (
 			#		or
 			#	(defined($value) and defined($last_value) and $value eq $last_value)
 			#);
-			#
-			#$last_value = $value;
-			#weaken $last_value if defined($last_value) and ref($last_value);
 
 			$self->emit(
-				args => {
-					value => $value,
-				},
-				event => (
+				-type => 'Reflex::Event::ValueChange',
+				-name => (
 					$event ||=
 					$self->meta->find_attribute_by_name($meta_self->name())->event()
 				),
+				old_value => $old_value,
+				new_value => $new_value,
 			);
+
+			$old_value = $new_value;
+			weaken $old_value if defined($old_value) and ref($old_value);
 		}
 	}
 );
@@ -63,13 +65,11 @@ has initializer => (
 			my ($self, $value, $callback, $attr) = @_;
 			my $event;
 			$self->emit(
-				args => {
-					value => $value,
-				},
-				event => (
+				-name => (
 					$event ||=
 					$self->meta->find_attribute_by_name($attr->name())->event()
 				),
+				value => $value,
 			);
 
 			$callback->($value);
@@ -97,8 +97,8 @@ sub emits {
 }
 
 package Moose::Meta::Attribute::Custom::Trait::Reflex::Trait::EmitsOnChange;
-BEGIN {
-  $Moose::Meta::Attribute::Custom::Trait::Reflex::Trait::EmitsOnChange::VERSION = '0.091';
+{
+  $Moose::Meta::Attribute::Custom::Trait::Reflex::Trait::EmitsOnChange::VERSION = '0.092';
 }
 sub register_implementation { 'Reflex::Trait::EmitsOnChange' }
 
@@ -118,7 +118,7 @@ Reflex::Trait::EmitsOnChange - Emit an event when an attribute's value changes.
 
 =head1 VERSION
 
-This document describes version 0.091, released on August 25, 2011.
+This document describes version 0.092, released on November 29, 2011.
 
 =head1 SYNOPSIS
 
